// matrix-appservice-kakaotalk - A Matrix-KakaoTalk puppeting bridge.
// Copyright (C) 2022 Tulir Asokan, Andrew Ferrazzutti
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU Affero General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Affero General Public License for more details.
//
// You should have received a copy of the GNU Affero General Public License
// along with this program.  If not, see <https://www.gnu.org/licenses/>.
import process from "process"
import fs from "fs"

import arg from "arg"
import sd from "systemd-daemon"

import ClientManager from "./clientmanager.js"


throw Error(
	"Using this bridge may currently cause your KakaoTalk to be BANNED! " +
	"If you wish to use it anyways, please remove this error from source code first."
)

const args = arg({
	"--config": String,
	"-c": "--config",
})

const configPath = args["--config"] || "config.json"

console.log("[Main] Reading config from", configPath)
const config = JSON.parse(fs.readFileSync(configPath).toString())

const manager = new ClientManager(
	config.listen,
	config.register_timeout,
	config.logging_keys
)

function stop() {
	manager.stop().then(() => {
		console.log("[Main] Everything stopped")
		process.exit(0)
	}, err => {
		console.error("[Main] Error stopping:", err)
		process.exit(3)
	})
}

manager.start().then(() => {
	process.once("SIGINT", stop)
	process.once("SIGTERM", stop)
	sd.notify("READY=1")
}, err => {
	console.error("[Main] Error starting:", err)
	process.exit(2)
})
